pub fn decide_embedding_read(
manifest: &EmbeddingGenerationManifest,
freshness: EmbeddingFreshness,
force_stale: bool,
) -> EmbeddingReadDecisionExpand description
Select the serving boundary for a classified verified generation.
pub fn decide_embedding_read(
manifest: &EmbeddingGenerationManifest,
freshness: EmbeddingFreshness,
force_stale: bool,
) -> EmbeddingReadDecisionSelect the serving boundary for a classified verified generation.