pub enum EmbeddingRefreshConfigUpdate {
SetProjectPolicy(EmbeddingRefreshProjectPolicy),
SetSpacePolicy {
compatibility_id: EmbeddingCompatibilityId,
policy: Option<EmbeddingRefreshSpacePolicy>,
},
RecordOutcome {
compatibility_id: EmbeddingCompatibilityId,
outcome: EmbeddingRefreshOutcomeRecord,
},
RemoveSpace {
compatibility_id: EmbeddingCompatibilityId,
},
}Expand description
One explicit mutation of durable refresh control state.
Variants
SetProjectPolicy(EmbeddingRefreshProjectPolicy)
Replace project-wide defaults.
SetSpacePolicy
Set or clear one lineage override. Clearing retains its last outcome.
Fields

compatibility_id: EmbeddingCompatibilityIdExact compatibility lineage.

policy: Option<EmbeddingRefreshSpacePolicy>Override to persist, or None to inherit project defaults.
RecordOutcome
Record one terminal content-free outcome.
Fields

compatibility_id: EmbeddingCompatibilityIdExact compatibility lineage.

outcome: EmbeddingRefreshOutcomeRecordNewest terminal outcome.
RemoveSpace
Remove all policy and outcome state for one lineage.
Fields

compatibility_id: EmbeddingCompatibilityIdExact compatibility lineage.