pub struct SearchSourceSnapshot {
pub generation: u64,
pub fingerprint: String,
}Expand description
Stable graph snapshot identity stored in a search manifest.
Fields
generation: u64Committed search-source generation.
fingerprint: StringCanonical content fingerprint.
Implementations
Sourceimpl SearchSourceSnapshot
impl SearchSourceSnapshot
Sourcepub fn capture(
project_dir: &Path,
parts: &[SearchSourcePart<'_>],
) -> Result<Self, SearchArtifactError>
pub fn capture( project_dir: &Path, parts: &[SearchSourcePart<'_>], ) -> Result<Self, SearchArtifactError>
Capture the current search generation and fingerprint the supplied logical source parts.
Errors
Returns a storage error for an unreadable generation or invalid source part list.