pub enum SearchUpdateBuild {
ReuseCurrent,
Publish,
}Expand description
Decision returned by an atomic primary-data update builder.
Variants
ReuseCurrent
The current immutable publication already contains the requested data.
Publish
The builder wrote a complete replacement into the supplied directory.